#!/usr/bin/python3

# Calculate APD, PDV, and End Time from data and pcap files.
# It output on the stdout the tables in .tex format.

import csv
import sys

# Bandwidth of the bottleneck link in B/s
bandwidth = 256000 # 2 Mbps

# Minimum segment size (B)
mss=500

# Transmission delay of the medium (s)
tr_delay=0.30


# Return a tuple, (average delay, worst packet delay variation)
def delaycalc (filetoopen):
    APD = 0
    PDV = 0
    avg_delay = -1
    pkt_min = 10000000

    # First pass: read the file line by line in order
    # to calculate the avg_delay and get the minimum number
    # of packets in the queue
    with open(filetoopen, 'r') as csvfile:
        spamreader = csv.reader(csvfile, delimiter='\t', quotechar='|')

        pkt_sum = 0
        samples_number = 0

        # The format of the file is:
        # Sec   Bytes   Pkts
        for row in spamreader:
            if row[0][0] == "#":
                continue

            pkt_number = int(row[2])

            if pkt_number < pkt_min:
                pkt_min = pkt_number

            pkt_sum += pkt_number
            samples_number += 1

        assert (samples_number != 0)

        avg_pkt = pkt_sum / samples_number
        avg_delay = (mss * avg_pkt / bandwidth) + tr_delay

    assert (pkt_min != 10000000)
    del_min = (mss * pkt_min / bandwidth) + tr_delay

    # Reopen the file, starts from the beginning, check every line
    # in order to get the worst case PDV
    with open(filetoopen, 'r') as csvfile:
        spamreader = csv.reader(csvfile, delimiter='\t', quotechar='|')

        for row in spamreader:
            if row[0][0] == "#":
                continue

            pkt = int(row[2])
            del_sample = (mss * pkt / bandwidth) + tr_delay

            if del_sample - del_min > PDV:
                PDV = del_sample - del_min

    return ("{0:.3f}".format(avg_delay), "{0:.3f}".format(PDV))

import subprocess

# Calculate the end time with the help of capinfos
def timetransread (pcap_file):
    out = subprocess.check_output(["capinfos", "-u", pcap_file])
    return ((str(out).split(':')[2].split(" ")[-2]))



for i in ["Cubic", "NewReno", "Bic", "Noordwijk", "Hybla", "HighSpeed"]:
    print("\\begin{table}")
    print("\\centering")
    print("\\footnotesize{")
    print("\\begin{tabular}{c|c|c|c|c|c|c|}")
    print("\cline{2-7}")
    print("\multicolumn{1}{l}{} & \multicolumn{3}{|c}{TCP "+i+"} & \multicolumn{3}{|c|}{TCP "+i+"+$\\Name$}")
    print("\\\\")
    print("\hline")
    print("\multicolumn{1}{|c|}{n} & APD (s) & PDV (s) & End (s) & APD (s) & PDV (s) & End (s)")
    print("\\\\")
    print("\\hline \\hline")

    for j in ["2", "4", "8", "16"]:
        prefix = "data/wj_"+i+"_"+j
        prefix_mw = "data/wj_"+i+"Mw_"+j

        q_stat = prefix+"_inf-gwqueue-statistics.data"
        q_stat_mw = prefix_mw+"_inf-gwqueue-statistics.data"
        pcap = prefix+"_std-sat-gateway-sat0.pcap"
        pcap_mw = prefix_mw+"_std-sat-gateway-sat0.pcap"

        avg_delay, PDV = delaycalc(q_stat)
        time = timetransread (pcap)

        avg_delay_mw, PDV_mw = delaycalc(q_stat_mw)
        time_mw = timetransread (pcap_mw)


        print("\\multicolumn{1}{|c|}{"+j+"}  & "+avg_delay+" & "+PDV+" & "+time+" & "+avg_delay_mw+" & "+PDV_mw+" & "+time_mw+" \\\\ \hline")

    print("\\end{tabular}")
    print("}")
    if i == "Cubic":
        print("\caption{Average Packet Delay and Packet\\\\Delay Variation summary for TCP "+i+"}")
    else:
        print("\caption{Average Packet Delay and Packet Delay Variation summary for TCP "+i+"}")

    print("\label{tab:delTab"+i+"}")
    print("\end{table}")

