#!/bin/bash

source ../conf.sh

GNUPLOT_FILE_QUEUE="${TRON_PATH}/figures/graph/script/queue.gnuplot"
GNUPLOT_FILE_RTT="${TRON_PATH}/figures/graph/script/rtt.gnuplot"
GNUPLOT_FILE_TX="${TRON_PATH}/figures/graph/script/tx.gnuplot" 

OUT_WJ="Cubic Bic Hybla HighSpeed NewReno Noordwijk"
dir=$(pwd)

args=""

for i in $OUT_WJ; do
    for j in 2 4 8 16; do
        args="$args \" c2ml-lan --ConfigurationFile=${INI_PATH}/wj_${i}_${j}_std.ini \""
        args="$args \" c2ml-lan --ConfigurationFile=${INI_PATH}/wj_${i}Mw_${j}_std.ini \""
        args="$args \" c2ml-lan --ConfigurationFile=${INI_PATH}/wj_${i}_${j}_inf.ini \""
        args="$args \" c2ml-lan --ConfigurationFile=${INI_PATH}/wj_${i}Mw_${j}_inf.ini \""
    done
done

for i in nomw_std nomw_inf mw_std mw_inf; do
    args="$args \" c2ml-lan --ConfigurationFile=$INI_PATH/wj_6_${i}.ini \""
done

cd $NS3_HOME_DIR

cmd="parallel \"$NS3_COMMAND \" ::: $args"
eval $cmd

if [ ! $? -eq 0 ]; then
    echo -en "FALLITO QUALCOSA"
    exit 1
fi

mv *.data *.pcap $OUTPUT_DATA_DIR

cd $dir

args=""

for i in $OUT_WJ; do
    for j in 2 4 8 16; do
        n=$(echo ${j}-1 | bc)

        for t in std inf; do
            for s in Mw ""; do
                args="${args} \"${CAPTCP} throughput -s 2.0 -t ${OUTPUT_DATA_DIR}/wj_${i}${s}_${j}_${t}-sat-gateway-sat0.pcap > ${OUTPUT_DATA_DIR}/wj_${i}${s}_${j}_${t}-throughput.data\""
                
                for k in $(seq 1 ${j}); do
                    args="${args} \"${CAPTCP} throughput -s 2.0 -f ${k} -t ${OUTPUT_DATA_DIR}/wj_${i}${s}_${j}_${t}-sat-gateway-sat0.pcap > ${OUTPUT_DATA_DIR}/wj_${i}${s}_${j}_${t}-throughput-${k}.data\""
                done
            done
        done
    done
done

for i in nomw_std nomw_inf mw_std mw_inf; do
    args="${args} \" ${CAPTCP} throughput -s 2.0 -t ${OUTPUT_DATA_DIR}/wj_6_${i}-sat-gateway-sat0.pcap > ${OUTPUT_DATA_DIR}/wj_6_${i}-throughput.data \""

    for j in $(seq 1 6); do
        args="${args} \" ${CAPTCP} throughput -s 2.0 -f ${j} -t ${OUTPUT_DATA_DIR}/wj_6_${i}-sat-gateway-sat0.pcap > ${OUTPUT_DATA_DIR}/wj_6_${i}-throughput-${j}.data \""
    done
done

cmd="time parallel ::: $args"
eval $cmd

if [ ! $? -eq 0 ]; then
    echo -en "FALLITO QUALCOSA"
    exit 1
fi

cd ..

python wj_calculator.py

cd script

echo "set output \"${OUTPUT_EPS_DIR}/wj_inf.eps\"" > tmp.gnuplot
echo "set ylabel \"Worst Jain's Fairness Index\"" >> tmp.gnuplot
echo "set style histogram rowstacked" >> tmp.gnuplot

line="plot "
line="${line} newhistogram \"2 Nodes\", \
     \"${OUTPUT_DATA_DIR}/wj_2_inf-wj.data\" u 2:xtic(1) t \"Without C^{2}ML\" ls 1 fs pattern 4, \
     '' u 3:xtic(1) t \"With C^{2}ML \" ls 2 fs pattern 5,"
for j in 4 8 16; do
    line="${line} newhistogram \"${j} Nodes\", \
        \"${OUTPUT_DATA_DIR}/wj_${j}_inf-wj.data\" u 2:xtic(1) notitle ls 1 fs pattern 4, \
        '' u 3:xtic(1) notitle ls 2 fs pattern 5,"
done
line="${line};"

echo $line >> tmp.gnuplot

cat wj.gnuplot tmp.gnuplot | gnuplot
rm tmp.gnuplot

echo "set output \"${OUTPUT_EPS_DIR}/wj_std.eps\"" > tmp.gnuplot
echo "set ylabel \"Worst Jain's Fairness Index\"" >> tmp.gnuplot
echo "set style histogram rowstacked" >> tmp.gnuplot

echo $line | sed "s/inf/std/g" >> tmp.gnuplot

cat wj.gnuplot tmp.gnuplot | gnuplot
rm tmp.gnuplot

echo "set output \"${OUTPUT_EPS_DIR}/wj_6.eps\"" > tmp.gnuplot
echo "set ylabel \"Worst Jain's Fairness Index\"" >> tmp.gnuplot
echo "set key outside below vertical center maxrows 1" >> tmp.gnuplot

sed -i "s/inf/Large/g" ${OUTPUT_DATA_DIR}/wj_6-wj.data
sed -i "s/std/Standard/g" ${OUTPUT_DATA_DIR}/wj_6-wj.data

echo "plot '${OUTPUT_DATA_DIR}/wj_6-wj.data' u 2:xtic(1) t \"Without C^{2}ML\" ls 1 fs pattern 4, \
    '' u 3:xtic(1) t \"With C^{2}ML\" ls 2 fs pattern 5 " >> tmp.gnuplot

cat wj_6.gnuplot tmp.gnuplot | gnuplot
rm tmp.gnuplot

for i in ${OUT_WJ}; do
    ./do_plot_queue.sh -f $i -e ${OUTPUT_EPS_DIR} -d ${OUTPUT_DATA_DIR} -g ${GNUPLOT_FILE_QUEUE}
    ./do_plot_rtt.sh -f $i -e ${OUTPUT_EPS_DIR} -d ${OUTPUT_DATA_DIR} -g ${GNUPLOT_FILE_RTT}
    ./do_plot_txdata.sh -f $i -e ${OUTPUT_EPS_DIR} -d ${OUTPUT_DATA_DIR} -g ${GNUPLOT_FILE_TX}
done
